rtopDisc will discretize an area for
regularization or calculation of Ghosh-distance
"rtopDisc"(object, params = list(),...)
"rtopDisc"(object, params = list(), bb = bbox(object), ...)
"rtopDisc"(object, params = list(), bb = bbox(object), ...)
"rtopDisc"(object, params = list(), ...)SpatialPolygons or SpatialPolygonsDataFrame
or rtopVariogram,
or an object with class rtop that includes one of the above
rtop package, set in getRtopParams. Typical parameters
to modify for this function are:
random or regular sampling,
regular sampling is the default.For the real areas, regular sampling appears to have computational advantages compared
with random sampling. In addition to the traditional regular sampling, rtop
also offers a third type of sampling which assures that the same discretization
points are used for overlapping areas.
Starting with a coarse grid covering the region of interest, this will for a certain support be refined till a requested minimum number of points from the grid is within the support. In this way, for areal supports, the number of points in the area with the largest number of points will be approximately four times the requested minimum number of points. This methods also assure that points used to discretize a large support will be reused when discretizing smaller supports within the large one, e.g. subcatchments within larger catchments.
rtop-package and rtopVariogram