rtop-packagegetRtopParams(params,newPar, observations, formulaString, ...)intamapParams or a list of parameters for modification
of the default parameterslist of parameters for updating params or for
modification of the default parameters.
Possible parameters with their defaults are given belowSpatialPolygonsDataFrame with observations,
used for setting some of the default parameterscreateRtopObject for more details.params or for
modification of the default parameters.
Possible parameters with their defaults are given below
unc
axp parameter of
axTicks.
axp parameter of
axTicks.
gstat.
gDistEst = gDistPred = gDist
maxdist from the prediction location are used for prediction
or simulation; if combined with nmax, both criteria apply
rtopDisc
varMat, and also controlling when to use parallel
processing in
rtopDisc, when
nAreas*params$rresol/100 > cnAreas
rtopKrige
rtopParams to be included in the
object described in rtop-packageSkoien J. O., R. Merz, and G. Bloschl. Top-kriging - geostatistics on stream networks. Hydrology and Earth System Sciences, 10:277-287, 2006
createRtopObject and rtop-package
# Create a new set of intamapParameters, with default parameters:
params = getRtopParams()
# Make modifications to the default list of parameters
params = getRtopParams(newPar = list(gDist = TRUE, nugget = FALSE))
# Make modifications to an existing list of parameters
params = getRtopParams(params = params, newPar = list(gDist = TRUE,
nugget = FALSE))
Run the code above in your browser using DataLab