SpatialPolygonsDataFrame
readAreas(object, adir=".",ftype = "xy",projection = NA, ...)SpatialPointsDataFrame
with observationsreadAreaInfoSpatialPolygonsDataFrame of observations
and/or predictionLocations, depending on the information given in object.
object is a file name, readAreaInfo will be called.
If it is a
SpatialPointsDataFrame with observations and/or
predictionLocations, the function will read areal data from files according
to the ID associated with each observation/predictionLocation. The function is of particular use when data are not available as
shape-files, or when the observations are not part of the shape-files.
This function is mainly for compatibility with the former FORTRAN-version.
The simplest way to read the data in that case is through readShapePoly
in the maptools-package or readOGR in
the rgdal-package. See
also rtop-package.