Usage
## S3 method for class 'rtop':
rtopKrige(object, varMatUpdate = FALSE, params = list(), ...)
## S3 method for class 'SpatialPolygonsDataFrame':
rtopKrige(object, predictionLocations = NULL,
varMatObs, varMatPredObs, varMat, params = list(),
formulaString, sel, ...)
## S3 method for class 'STSDF':
rtopKrige(object, predictionLocations = NULL,
varMatObs, varMatPredObs, varMat, params = list(),
formulaString, sel, olags = NULL, plags = NULL,
lagExact = TRUE, ...)
## S3 method for class 'default':
rtopKrige(object, predictionLocations = NULL,
varMatObs, varMatPredObs, varMat, params = list(),
formulaString, sel, wret = FALSE, ...)Arguments
varMatUpdate
logical; if TRUE, also existing variance matrices will
be recomputed, if FALSE, only missing variance matrices will be computed,
see also varMat varMatObs
covariance matrix of observations, where diagonal must consist
of internal variance, typically generated from call
to varMat varMatPredObs
covariance matrix between observation locations and
prediction locations, typically generated from call
to varMat varMat
list covariance matrices including the two above
params
a set of parameters, used to modify the standard parameters for
the rtop package, set in getRtopParams. Additionally,
it is possible overrule some of the parameters in formulaString
formula that defines the dependent variable as a linear model
of independent variables, see e.g. createRtopObject for more details. sel
array of prediction location numbers, if only a limited number of locations are to be
interpolated/crossvalidated
wret
logical; if TRUE, return a matrix of weights instead of the predictions,
useful for batch processing of time series, see also details
olags
A vector describing the relative lag which should be applied for the observation locations. See also details
plags
A vector describing the relative lag which should be applied for the predicitonLocations. See also details
lagExact
logical; whether differences in lagtime should be computed exactly or approximate
...
from rtopKrige.rtop, arguments to be passed to
rtopKrige.default. In rtopKrige.default,
parameters for modification of the object parameters or default parameters.
Of particular interest are cv<